@@ -50,13 +50,14 @@ rar = "application/rar",
 rdf = "application/rdf+xml",
 rtf = "application/rtf",
 stl = "application/sla",
-smi = "application/smil",
-smil = "application/smil",
+smi = "application/smil+xml",
+smil = "application/smil+xml",
 xhtml = "application/xhtml+xml",
 xht = "application/xhtml+xml",
 xml = "application/xml",
-xsl = "application/xml",
 xsd = "application/xml",
+xsl = "application/xslt+xml",
+xslt = "application/xslt+xml",
 xspf = "application/xspf+xml",
 zip = "application/zip",
 apk = "application/vnd.android.package-archive",
@@ -291,6 +292,7 @@ m4a = "audio/mpeg",
 m3u = "audio/mpegurl",
 oga = "audio/ogg",
 ogg = "audio/ogg",
+opus = "audio/ogg",
 spx = "audio/ogg",
 sid = "audio/prs.sid",
 aif = "audio/x-aiff",
@@ -379,9 +381,14 @@ xtel = "chemical/x-xtel",
 xyz = "chemical/x-xyz",
 gif = "image/gif",
 ief = "image/ief",
+jp2 = "image/jp2",
+jpg2 = "image/jp2",
 jpeg = "image/jpeg",
 jpg = "image/jpeg",
 jpe = "image/jpeg",
+jpm = "image/jpm",
+jpx = "image/jpx",
+jpf = "image/jpx",
 pcx = "image/pcx",
 png = "image/png",
 svg = "image/svg+xml",
@@ -446,6 +453,7 @@ sct = "text/scriptlet",
 wsc = "text/scriptlet",
 tm = "text/texmacs",
 tsv = "text/tab-separated-values",
+ttl = "text/turtle",
 jad = "text/vnd.sun.j2me.app-descriptor",
 wml = "text/vnd.wap.wml",
 wmls = "text/vnd.wap.wmlscript",
